==> ciao-4.6-src-core.tar.gz: ciao-4.6/src/lib/datamodel/modules/pyregion/pyregion.h <==
/*                                                                
**  Copyright (C) 2010  Smithsonian Astrophysical Observatory 
*/                                                                

/*                                                                          */
/*  This program is free software; you can redistribute it and/or modify    */
/*  it under the terms of the GNU General Public License as published by    */
/*  the Free Software Foundation; either version 3 of the License, or       */
/*  (at your option) any later version.                                     */
/*                                                                          */
/*  This program is distributed in the hope that it will be useful,         */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/*  GNU General Public License for more details.                            */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License along */
/*  with this program; if not, write to the Free Software Foundation, Inc., */
/*  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             */
/*                                                                          */


/* *****************************************************************
 *
 * FILE NAME:  pyregion.h
 *
 * DEVELOPMENT: CXC Region
 *
 * DESCRIPTION:
 *    header info for CXC region python module
 *
 *
 * REVISION HISTORY:
 *
 ***************************************************************** */
#ifndef PYREGION_H
#define PYREGION_H

#include "Python.h"
#include <numpy/noprefix.h>
#include <numpy/arrayobject.h>

#include "cxcregion.h"
#include "ascdm.h"
#include <float.h>


void init_region(void);

typedef struct {
  PyObject_HEAD
  regRegion *reg;
} pyRegion;


#ifdef REGMODULE  /* for compiling this module */

/* Macros to cast NumPy array data to a 1-d array of the specified type. */
#define IDATA(p) ((int *)    (((PyArrayObject *)p)->data))
#define SDATA(p) ((short *)  (((PyArrayObject *)p)->data))
#define DDATA(p) ((double *) (((PyArrayObject *)p)->data))


/* module prototypes */
static PyObject* pyRegion_new( PyTypeObject *type, PyObject *args, PyObject *kwds );
static void      pyRegion_dealloc( pyRegion* self );
static PyObject* _regArea(PyObject *self, PyObject *args );
static PyObject* _regExtent(PyObject *self, PyObject *args );
static PyObject* _regInsideRegion(PyObject *self, PyObject *args );
static PyObject* _regParse(PyObject *self, PyObject *args );
static PyObject* _regPrintRegion(PyObject *self, PyObject *args );
static PyObject* _regRegionString(PyObject *self, PyObject *args );


#else            /* for other module extensions using this API */

static void **PyRegion_API = NULL;

#define Region_Type (*(PyTypeObject *)PyRegion_API[0])
#define pyRegion_New (*(PyObject* (*)( regRegion* )) PyRegion_API[1])


/* import method */
static int import_region(void)
{
  PyObject* m     = NULL;
  PyObject* c_api = NULL;
  int retval = -1;

  /* PyCapsule replaces PyCObject post python  v2.7??              */
  /*  PyRegion_API = (void**)PyCapsule_Import("region._C_API",0);  */

  m = PyImport_ImportModule((char*)"region");
  if ( m == NULL )
    goto fail;

  c_api = PyObject_GetAttrString( m, (char*)"C_API");
  if ( c_api == NULL )
    goto fail;

  if (PyCObject_Check(c_api) )
    PyRegion_API = (void**)PyCObject_AsVoidPtr(c_api);

  if ( PyRegion_API == NULL )
    goto fail;

  /* all is good */
  retval = 0;

 fail:
  Py_XDECREF(m);
  Py_XDECREF(c_api);

  return retval;
}
#endif /* end C API import definition */

#endif

==> ciao-4.8-src-core.tar.gz: ciao-4.8/src/lib/datamodel/modules/pyregion/pyregion.h <==
/*                                                                
**  Copyright (C) 2010  Smithsonian Astrophysical Observatory 
*/                                                                

/*                                                                          */
/*  This program is free software; you can redistribute it and/or modify    */
/*  it under the terms of the GNU General Public License as published by    */
/*  the Free Software Foundation; either version 3 of the License, or       */
/*  (at your option) any later version.                                     */
/*                                                                          */
/*  This program is distributed in the hope that it will be useful,         */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/*  GNU General Public License for more details.                            */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License along */
/*  with this program; if not, write to the Free Software Foundation, Inc., */
/*  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             */
/*                                                                          */


/* *****************************************************************
 *
 * FILE NAME:  pyregion.h
 *
 * DEVELOPMENT: CXC Region
 *
 * DESCRIPTION:
 *    header info for CXC region python module
 *
 *
 * REVISION HISTORY:
 *
 ***************************************************************** */
/* Tool has been cleaned to Numpy API version 1.7 */
#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION

#ifndef PYREGION_H
#define PYREGION_H

#include "Python.h"
#include <numpy/noprefix.h>
#include <numpy/arrayobject.h>

#include "cxcregion.h"
#include "ascdm.h"
#include <float.h>


void init_region(void);

typedef struct {
  PyObject_HEAD
  regRegion *reg;
} pyRegion;


#ifdef REGMODULE  /* for compiling this module */

/* Macros to cast NumPy array data to a 1-d array of the specified type. */
#define IDATA(p) ((int *)    (PyArray_DATA(((PyArrayObject *)p))))
#define SDATA(p) ((short *)  (PyArray_DATA(((PyArrayObject *)p))))
#define DDATA(p) ((double *) (PyArray_DATA(((PyArrayObject *)p))))


/* module prototypes */
static PyObject* pyRegion_new( PyTypeObject *type, PyObject *args, PyObject *kwds );
static void      pyRegion_dealloc( pyRegion* self );
static PyObject* _regArea(PyObject *self, PyObject *args );
static PyObject* _regExtent(PyObject *self, PyObject *args );
static PyObject* _regInsideRegion(PyObject *self, PyObject *args );
static PyObject* _regParse(PyObject *self, PyObject *args );
static PyObject* _regPrintRegion(PyObject *self, PyObject *args );
static PyObject* _regRegionString(PyObject *self, PyObject *args );


#else            /* for other module extensions using this API */

static void **PyRegion_API = NULL;

#define Region_Type (*(PyTypeObject *)PyRegion_API[0])
#define pyRegion_New (*(PyObject* (*)( regRegion* )) PyRegion_API[1])


/* import method */
static int import_region(void)
{
  PyObject* m     = NULL;
  PyObject* c_api = NULL;
  int retval = -1;

  /* PyCapsule replaces PyCObject post python  v2.7??              */
  /*  PyRegion_API = (void**)PyCapsule_Import("region._C_API",0);  */

  m = PyImport_ImportModule((char*)"region");
  if ( m == NULL )
    goto fail;

  c_api = PyObject_GetAttrString( m, (char*)"C_API");
  if ( c_api == NULL )
    goto fail;

  if (PyCObject_Check(c_api) )
    PyRegion_API = (void**)PyCObject_AsVoidPtr(c_api);

  if ( PyRegion_API == NULL )
    goto fail;

  /* all is good */
  retval = 0;

 fail:
  Py_XDECREF(m);
  Py_XDECREF(c_api);

  return retval;
}
#endif /* end C API import definition */

#endif
